about summary refs log tree commit diff stats
diff options
context:
space:
mode:
-rw-r--r--examples/shell_automatic_cd.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/shell_automatic_cd.sh b/examples/shell_automatic_cd.sh
index 391946c7..6158f74a 100644
--- a/examples/shell_automatic_cd.sh
+++ b/examples/shell_automatic_cd.sh
@@ -19,5 +19,5 @@ ranger_cd() {
     rm -f -- "$temp_file"
 }
 
-# This binds Ctrl-O to ranger-cd:
-bind '"\C-o":"ranger-cd\C-m"'
+# This binds Ctrl-O to ranger_cd:
+bind '"\C-o":"ranger_cd\C-m"'